==> aws-cdk.aws-codebuild-1.75.0.tar.gz: package/lib/linux-gpu-build-image.d.ts <==
import * as core from '@aws-cdk/core';
import { BuildSpec } from './build-spec';
import { BuildEnvironment, BuildImageBindOptions, BuildImageConfig, ComputeType, IBindableBuildImage, IBuildImage, ImagePullPrincipalType, IProject } from './project';
/**
 * A CodeBuild GPU image running Linux.
 *
 * This class has public constants that represent the most popular GPU images from AWS Deep Learning Containers.
 *
 * @see https://aws.amazon.com/releasenotes/available-deep-learning-containers-images
 */
export declare class LinuxGpuBuildImage implements IBindableBuildImage {
    private readonly repositoryName;
    private readonly account;
    /**
     * Tensorflow 1.14.0 GPU image from AWS Deep Learning Containers.
     */
    static readonly DLC_TENSORFLOW_1_14_0: IBuildImage;
    /**
     * Tensorflow 1.15.0 GPU image from AWS Deep Learning Containers.
     */
    static readonly DLC_TENSORFLOW_1_15_0: IBuildImage;
    /**
     * Tensorflow 1.15.2 GPU training image from AWS Deep Learning Containers.
     */
    static readonly DLC_TENSORFLOW_1_15_2_TRAINING: IBuildImage;
    /**
     * Tensorflow 1.15.2 GPU inference image from AWS Deep Learning Containers.
     */
    static readonly DLC_TENSORFLOW_1_15_2_INFERENCE: IBuildImage;
    /**
     * Tensorflow 2.0.0 GPU image from AWS Deep Learning Containers.
     */
    static readonly DLC_TENSORFLOW_2_0_0: IBuildImage;
    /**
     * Tensorflow 2.0.1 GPU image from AWS Deep Learning Containers.
     */
    static readonly DLC_TENSORFLOW_2_0_1: IBuildImage;
    /**
     * Tensorflow 2.1.0 GPU training image from AWS Deep Learning Containers.
     */
    static readonly DLC_TENSORFLOW_2_1_0_TRAINING: IBuildImage;
    /**
     * Tensorflow 2.1.0 GPU inference image from AWS Deep Learning Containers.
     */
    static readonly DLC_TENSORFLOW_2_1_0_INFERENCE: IBuildImage;
    /**
     * Tensorflow 2.2.0 GPU training image from AWS Deep Learning Containers.
     */
    static readonly DLC_TENSORFLOW_2_2_0_TRAINING: IBuildImage;
    /**
     * PyTorch 1.2.0 GPU image from AWS Deep Learning Containers.
     */
    static readonly DLC_PYTORCH_1_2_0: IBuildImage;
    /**
     * PyTorch 1.3.1 GPU image from AWS Deep Learning Containers.
     */
    static readonly DLC_PYTORCH_1_3_1: IBuildImage;
    /**
     * PyTorch 1.4.0 GPU training image from AWS Deep Learning Containers.
     */
    static readonly DLC_PYTORCH_1_4_0_TRAINING: IBuildImage;
    /**
     * PyTorch 1.4.0 GPU inference image from AWS Deep Learning Containers.
     */
    static readonly DLC_PYTORCH_1_4_0_INFERENCE: IBuildImage;
    /**
     * PyTorch 1.5.0 GPU training image from AWS Deep Learning Containers.
     */
    static readonly DLC_PYTORCH_1_5_0_TRAINING: IBuildImage;
    /**
     * PyTorch 1.5.0 GPU inference image from AWS Deep Learning Containers.
     */
    static readonly DLC_PYTORCH_1_5_0_INFERENCE: IBuildImage;
    /**
     * MXNet 1.4.1 GPU image from AWS Deep Learning Containers.
     */
    static readonly DLC_MXNET_1_4_1: IBuildImage;
    /**
     * MXNet 1.6.0 GPU image from AWS Deep Learning Containers.
     */
    static readonly DLC_MXNET_1_6_0: IBuildImage;
    /**
     * Returns a Linux GPU build image from AWS Deep Learning Containers.
     *
     * @param repositoryName the name of the repository, for example "pytorch-inference".
     * @param tag the tag of the image, for example "1.5.0-gpu-py36-cu101-ubuntu16.04".
     * @param account the AWS account ID where the DLC repository for this region is hosted in.
     * @see https://aws.amazon.com/releasenotes/available-deep-learning-containers-images
     */
    static awsDeepLearningContainersImage(repositoryName: string, tag: string, account?: string): IBuildImage;
    /**
     * The type of build environment.
     */
    readonly type = "LINUX_GPU_CONTAINER";
    /**
     * The default {@link ComputeType} to use with this image, if one was not specified in {@link BuildEnvironment#computeType} explicitly.
     */
    readonly defaultComputeType = ComputeType.LARGE;
    /**
     * The Docker image identifier that the build environment uses.
     */
    readonly imageId: string;
    /**
     * The type of principal that CodeBuild will use to pull this build Docker image.
     */
    readonly imagePullPrincipalType?: ImagePullPrincipalType;
    private readonly accountExpression;
    private constructor();
    /**
     * Function that allows the build image access to the construct tree.
     */
    bind(scope: core.Construct, project: IProject, _options: BuildImageBindOptions): BuildImageConfig;
    /**
     * Allows the image a chance to validate whether the passed configuration is correct.
     */
    validate(buildEnvironment: BuildEnvironment): string[];
    /**
     * Make a buildspec to run the indicated script.
     */
    runScriptBuildspec(entrypoint: string): BuildSpec;
}

==> aws-cdk.aws-codebuild-1.125.0.tar.gz: package/lib/linux-gpu-build-image.d.ts <==
import { BuildSpec } from './build-spec';
import { BuildEnvironment, BuildImageBindOptions, BuildImageConfig, ComputeType, IBindableBuildImage, IBuildImage, ImagePullPrincipalType, IProject } from './project';
import { Construct } from '@aws-cdk/core';
/**
 * A CodeBuild GPU image running Linux.
 *
 * This class has public constants that represent the most popular GPU images from AWS Deep Learning Containers.
 *
 * @see https://aws.amazon.com/releasenotes/available-deep-learning-containers-images
 * @stability stable
 */
export declare class LinuxGpuBuildImage implements IBindableBuildImage {
    private readonly repositoryName;
    private readonly account;
    /**
     * Tensorflow 1.14.0 GPU image from AWS Deep Learning Containers.
     *
     * @stability stable
     */
    static readonly DLC_TENSORFLOW_1_14_0: IBuildImage;
    /**
     * Tensorflow 1.15.0 GPU image from AWS Deep Learning Containers.
     *
     * @stability stable
     */
    static readonly DLC_TENSORFLOW_1_15_0: IBuildImage;
    /**
     * Tensorflow 1.15.2 GPU training image from AWS Deep Learning Containers.
     *
     * @stability stable
     */
    static readonly DLC_TENSORFLOW_1_15_2_TRAINING: IBuildImage;
    /**
     * Tensorflow 1.15.2 GPU inference image from AWS Deep Learning Containers.
     *
     * @stability stable
     */
    static readonly DLC_TENSORFLOW_1_15_2_INFERENCE: IBuildImage;
    /**
     * Tensorflow 2.0.0 GPU image from AWS Deep Learning Containers.
     *
     * @stability stable
     */
    static readonly DLC_TENSORFLOW_2_0_0: IBuildImage;
    /**
     * Tensorflow 2.0.1 GPU image from AWS Deep Learning Containers.
     *
     * @stability stable
     */
    static readonly DLC_TENSORFLOW_2_0_1: IBuildImage;
    /**
     * Tensorflow 2.1.0 GPU training image from AWS Deep Learning Containers.
     *
     * @stability stable
     */
    static readonly DLC_TENSORFLOW_2_1_0_TRAINING: IBuildImage;
    /**
     * Tensorflow 2.1.0 GPU inference image from AWS Deep Learning Containers.
     *
     * @stability stable
     */
    static readonly DLC_TENSORFLOW_2_1_0_INFERENCE: IBuildImage;
    /**
     * Tensorflow 2.2.0 GPU training image from AWS Deep Learning Containers.
     *
     * @stability stable
     */
    static readonly DLC_TENSORFLOW_2_2_0_TRAINING: IBuildImage;
    /**
     * PyTorch 1.2.0 GPU image from AWS Deep Learning Containers.
     *
     * @stability stable
     */
    static readonly DLC_PYTORCH_1_2_0: IBuildImage;
    /**
     * PyTorch 1.3.1 GPU image from AWS Deep Learning Containers.
     *
     * @stability stable
     */
    static readonly DLC_PYTORCH_1_3_1: IBuildImage;
    /**
     * PyTorch 1.4.0 GPU training image from AWS Deep Learning Containers.
     *
     * @stability stable
     */
    static readonly DLC_PYTORCH_1_4_0_TRAINING: IBuildImage;
    /**
     * PyTorch 1.4.0 GPU inference image from AWS Deep Learning Containers.
     *
     * @stability stable
     */
    static readonly DLC_PYTORCH_1_4_0_INFERENCE: IBuildImage;
    /**
     * PyTorch 1.5.0 GPU training image from AWS Deep Learning Containers.
     *
     * @stability stable
     */
    static readonly DLC_PYTORCH_1_5_0_TRAINING: IBuildImage;
    /**
     * PyTorch 1.5.0 GPU inference image from AWS Deep Learning Containers.
     *
     * @stability stable
     */
    static readonly DLC_PYTORCH_1_5_0_INFERENCE: IBuildImage;
    /**
     * MXNet 1.4.1 GPU image from AWS Deep Learning Containers.
     *
     * @stability stable
     */
    static readonly DLC_MXNET_1_4_1: IBuildImage;
    /**
     * MXNet 1.6.0 GPU image from AWS Deep Learning Containers.
     *
     * @stability stable
     */
    static readonly DLC_MXNET_1_6_0: IBuildImage;
    /**
     * Returns a Linux GPU build image from AWS Deep Learning Containers.
     *
     * @param repositoryName the name of the repository, for example "pytorch-inference".
     * @param tag the tag of the image, for example "1.5.0-gpu-py36-cu101-ubuntu16.04".
     * @param account the AWS account ID where the DLC repository for this region is hosted in.
     * @see https://aws.amazon.com/releasenotes/available-deep-learning-containers-images
     * @stability stable
     */
    static awsDeepLearningContainersImage(repositoryName: string, tag: string, account?: string): IBuildImage;
    /**
     * The type of build environment.
     *
     * @stability stable
     */
    readonly type = "LINUX_GPU_CONTAINER";
    /**
     * The default {@link ComputeType} to use with this image, if one was not specified in {@link BuildEnvironment#computeType} explicitly.
     *
     * @stability stable
     */
    readonly defaultComputeType = ComputeType.LARGE;
    /**
     * The Docker image identifier that the build environment uses.
     *
     * @stability stable
     */
    readonly imageId: string;
    /**
     * The type of principal that CodeBuild will use to pull this build Docker image.
     *
     * @stability stable
     */
    readonly imagePullPrincipalType?: ImagePullPrincipalType;
    private readonly accountExpression;
    private constructor();
    /**
     * Function that allows the build image access to the construct tree.
     *
     * @stability stable
     */
    bind(scope: Construct, project: IProject, _options: BuildImageBindOptions): BuildImageConfig;
    /**
     * Allows the image a chance to validate whether the passed configuration is correct.
     *
     * @stability stable
     */
    validate(buildEnvironment: BuildEnvironment): string[];
    /**
     * Make a buildspec to run the indicated script.
     *
     * @stability stable
     */
    runScriptBuildspec(entrypoint: string): BuildSpec;
}
